<?php
/**
 * Class to check opening_hours as used by the OpenStreetMap project
 *
 * This code is a port of the javascript code from
 * http://www.netzwolf.info/kartografie/osm/time_domain/
 *
 * PHP version 5.1.0+
 *
 * Copyright (c) 2012, Uwe Steinmann
 * 
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 *
 *  - Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *  - Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *  - Neither the name of the The PEAR Group nor the names of its contributors 
 *    may be used to endorse or promote products derived from this software 
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * @category  OSM
 * @package   OSM_OpeningHours
 * @author    Uwe Steinmann <steinm@php.net>
 * @copyright 2012 Uwe Steinmann
 * @license   http://www.opensource.org/licenses/bsd-license.php New BSD License
 * @version   CVS: $Revision: $
 * @link      http://pear.php.net/package/OSM_OpeningHours
 */

/**
 * Class for representing a date as used in javascript
 *
 * @category  OSM
 * @package   OSM_OpeningHours
 * @author    Uwe Steinmann <steinm@php.net>
 * @copyright 2012 Uwe Steinmann
 * @license   http://www.opensource.org/licenses/bsd-license.php New BSD License
 * @link      http://pear.php.net/package/OSM_OpeningHours
 */
class OSM_OpeningHours_Date { /* {{{ */
	/**
	 * unix timestamp
	 *
	 * @var integer $_timestamp
	 * @access private
	 */
	private $_timestamp;

	/**
	 * Constructor
	 *
	 * @param integer $y either the year a timestamp in milliseconds or void
	 * @param integer $m month of year if first parameter was a year or void
	 * @param integer $d day of month or void
	 * @param integer $H hour of day or void
	 * @param integer $M minute or void
	 * @param integer $S seconds or void
	 * @return void
	 */
	function __construct($y=0, $m=0, $d=0, $H=0, $M=0, $S=0) { /* {{{ */
		if($y == 0) /* no parameter at all -> current date */
			$this->_timestamp = time();
		elseif($y > 0 && $m == 0 && $d == 0) /* Treat as timestamp in milliseconds */
			$this->_timestamp = $y / 1000;
		else { /* date specified in 6 components */
			$this->_timestamp = mktime($H, $M, $S, $m, $d, $y);
		}
	} /* }}} */

	/**
	 * Get seconds of date
	 *
	 * @return integer
	 */
	public function getSeconds() { /* {{{ */
		if($this->_timestamp)
			return (int) date('s', $this->_timestamp);
		else
			return false;
	} /* }}} */

	/**
	 * Get minutes of date
	 *
	 * @return integer
	 */
	public function getMinutes() { /* {{{ */
		if($this->_timestamp)
			return (int) date('i', $this->_timestamp);
		else
			return false;
	} /* }}} */

	public function getHours() { /* {{{ */
		if($this->_timestamp)
			return (int) date('H', $this->_timestamp);
		else
			return false;
	} /* }}} */

	public function getDate() { /* {{{ */
		if($this->_timestamp)
			return (int) date('d', $this->_timestamp);
		else
			return false;
	} /* }}} */

	public function getMonth() { /* {{{ */
		if($this->_timestamp)
			return ((int) date('n', $this->_timestamp));
		else
			return false;
	} /* }}} */

	public function getFullYear() { /* {{{ */
		if($this->_timestamp)
			return (int) date('Y', $this->_timestamp);
		else
			return false;
	} /* }}} */

	/**
	 * Get timestamp in milliseconds
	 *
	 * @return integer
	 */
	public function getTime() { /* {{{ */
		return($this->_timestamp * 1000);
	} /* }}} */

	/**
	 * Get unix timestamp in seconds
	 *
	 * @return integer
	 */
	public function getUnixTimestamp() { /* {{{ */
		return($this->_timestamp);
	} /* }}} */

} /* }}} */
?>
